﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using MySql.Data.MySqlClient;

namespace AjpdSoftAccesoMySQLCsharp
{
    public partial class formAccesoMySQL : Form
    {
        private MySqlConnection conexionBD;

        private void obtenerBasesDatosMySQL ()
        {
            MySqlDataReader registrosObtenidosMySQL = null;

            MySqlCommand cmd = 
                new MySqlCommand("SHOW DATABASES", conexionBD);
            try
            {
                registrosObtenidosMySQL = cmd.ExecuteReader();
                lsBD.Items.Clear();
                while (registrosObtenidosMySQL.Read())
                {
                    lsBD.Items.Add(registrosObtenidosMySQL.GetString(0));
                }
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("Error al obtener bases de datos de MySQL: " + 
                    ex.Message,"Error al obtener catálogos",
                    MessageBoxButtons.OK,MessageBoxIcon.Error);
            }
            finally
            {
                if (registrosObtenidosMySQL != null) 
                    registrosObtenidosMySQL.Close();
            }
        }

        private void obtenerTablasBDMysql(string bd)
        {
            MySqlDataReader reader = null;

            try
            {
                conexionBD.ChangeDatabase(bd);

                MySqlCommand cmd = new MySqlCommand("SHOW TABLES", conexionBD);
                reader = cmd.ExecuteReader();
                lsTablas.Items.Clear();
                while (reader.Read())
                {
                    lsTablas.Items.Add(reader.GetString(0));
                }
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("Error al obtener la lista de tablas " +
                    "de la BD de MySQL: " + 
                    ex.Message,"Error obtener tablas",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
                if (reader != null) reader.Close();
            }
        }

        public formAccesoMySQL()
        {
            InitializeComponent();
        }

        private void btConectar_Click(object sender, EventArgs e)
        {
            if (conexionBD != null)
                conexionBD.Close();

            string connStr =
                String.Format("server={0};port={1};user id={2}; password={3}; " + 
                "database=mysql; pooling=false;" +
                "Allow Zero Datetime=False;Convert Zero Datetime=True",
                txtServidor.Text,txtPuerto.Text, txtUsuario.Text, txtContrasena.Text);
            try
            {
                conexionBD = new MySqlConnection(connStr);
                conexionBD.Open();

                obtenerBasesDatosMySQL();
            }
            catch (MySqlException ex)
            {
                MessageBox.Show("Error al conectar al servidor de MySQL: " + 
                    ex.Message, "Error al conectar", 
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btSelectSQL_Click(object sender, EventArgs e)
        {
            txtSQL.Text = "select * from " + lsTablas.Text;
        }

        private void btUsarEsquema_Click(object sender, EventArgs e)
        {
            obtenerTablasBDMysql(lsBD.Text);
        }

        private void btEjecutar_Click(object sender, EventArgs e)
        {
            if (opDatos.Checked)
            {
                DataTable tabla;
                MySqlDataAdapter datosAdapter;
                MySqlCommandBuilder comandoSQL;

                try
                {
                    tabla = new DataTable();

                    datosAdapter = new MySqlDataAdapter(txtSQL.Text, conexionBD);
                    comandoSQL = new MySqlCommandBuilder(datosAdapter);

                    datosAdapter.Fill(tabla);

                    dbGrid.DataSource = tabla;
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error al mostrar los datos de la tabla [" +
                        lsTablas.Text + "] de MySQL: " + 
                        ex.Message, "Error ejecutar SQL",
                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
            if (opNoDatos.Checked)
            {
                try
                {
                    int numeroRegistrosAfectados = 0;

                    MySqlCommand cmd = new MySqlCommand();
                    cmd.Connection = conexionBD;
                    cmd.CommandText = txtSQL.Text;
                    cmd.Prepare();                
                    numeroRegistrosAfectados = cmd.ExecuteNonQuery();
                    MessageBox.Show("Consulta de modificación de datos " +
                        "ejecutada, número de registros afectados: " +
                        Convert.ToString(numeroRegistrosAfectados) + ".", 
                        "Consulta SQL ejecutada",
                        MessageBoxButtons.OK, MessageBoxIcon.Information);
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error ejecutar consulta de " +
                        "modificación de datos: " +
                        ex.Message, "Error ejecutar SQL",
                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void linkAjpdSoft_LinkClicked(object sender, 
            LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://www.ajpdsoft.com");
        }
    }
}
